package main

import (
	"flag"
	"fmt"
	"log"

	"git.autistici.org/ale/autoradio"
	"git.autistici.org/ale/autoradio/fe"
)

var (
	domain = flag.String("domain", "", "DNS domain to serve")
	dnsPort = flag.Int("dns-port", 53, "DNS port")
	httpPort = flag.Int("http-port", 80, "HTTP port")
	publicIp = flag.String("ip", "127.0.0.1", "Public IP for this machine")

	staticDir = flag.String("static-dir", "/usr/share/autoradio/htdocs/static", "Static content directory")
	templateDir = flag.String("template-dir", "/usr/share/autoradio/htdocs/templates", "HTML templates directory")

	lbPolicy = flag.String("lb-policy", "weighted", "Load balancing policy (weighted, leastloaded)")

	// Default DNS TTL (seconds).
	dnsTtl = 5
)

func main() {
	flag.Parse()

	if *domain == "" {
		log.Fatal("Must specify --domain")
	}

	client := autoradio.NewEtcdClient()
	api := autoradio.NewRadioAPI(client)

	dnsRed := fe.NewDnsRedirector(api, *domain, *publicIp, dnsTtl)
	dnsRed.Run(fmt.Sprintf(":%d", *dnsPort))

	red := fe.NewHttpRedirector(api, *domain, *lbPolicy)
	red.Run(fmt.Sprintf(":%d", *httpPort), *staticDir, *templateDir)
}
