# Common functions for the 'autoradio' startup scripts.

PATH=/bin:/usr/bin:/sbin:/usr/sbin:/usr/local/bin:$PATH
export PATH

test -e /etc/default/autoradio && . /etc/default/autoradio

if [ -z "${DOMAIN}" ]; then
    echo "You must set DOMAIN in /etc/default/autoradio!" 1>&2
    exit 1
fi

resolveall() {
    local name="$1"
    local port="$2"
    getent hosts ${name} | awk "{print \$1 \":${port}\"}"
}

commaseplist() {
    local out=
    for arg in "$@" ; do
        out="${out}${out:+,}${arg}"
    done
    echo "${out}"
}

set_public_ip() {
    # Try to guess the public IP of this host if unset, resolving the
    # fully-qualified host name.
    if [ -z "${PUBLIC_IP}" ]; then
        PUBLIC_IP=$(getent hosts $(hostname -f) | awk '{print $1}' | head -1)
    fi
    if [ -z "${PUBLIC_IP}" ]; then
        PUBLIC_IP=127.0.0.1
    fi
}

set_etcd_params() {
    local default_etcd_server="etcd.${DOMAIN}"
    ETCD_SERVER="${ETCD_SERVER:-${default_etcd_server}}"
    local server_ips=$(commaseplist localhost:4001 $(resolveall ${ETCD_SERVER} 4001))
    ETCD_OPTIONS="${ETCD_OPTIONS} --etcd-servers=${server_ips}"
}
